=============
Inibin reader
=============

A module for reading League of Legends inibin files.

::

    Usage:
      python -m inibin <file>
      python -m inibin <kind> <file>

    Arguments:
      <file> -- path to an inibin file
      <kind> -- what to interpret the inibin as, must be champion or ability

